@@ -189,7 +189,9 @@ def _port_mapping_format(port_mappings: List[Job2PortMapping]) -> str:
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-GPULAB_VERSION = '3.7.0'
+from ._version import __version__
+GPULAB_VERSION = __version__
+
 
 
 def check_and_warn_version(ctx):
@@ -347,7 +349,7 @@ def modify_usage_error():
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def cli(ctx: click.Context, cert, password, deployment_environment: str, servercert, debug, custom_master_url):
-    """GPULab client version 3.7.0
+    f"""GPULab client version {GPULAB_VERSION}
 
     \b
     This is the general help. For help with a specific command, try:
@@ -602,7 +604,7 @@ def print_bugreport_context(ctx):
 @click.version_option(GPULAB_VERSION, message='%(version)s')
 @click.pass_context
 def localhost_mode_cli(ctx):
-    """GPULab client version 3.7.0 (in LOCALHOST_MODE!)
+    f"""GPULab client version {GPULAB_VERSION} (in LOCALHOST_MODE!)
 
     \b
     Send bugreports, questions and feedback to: gpulab@ilabt.imec.be
@@ -755,7 +757,7 @@ def run_interactive(ctx, project, duration_minutes, docker_image, proxy, ssh_pub
             "docker": {
                 "image": docker_image,
                 "command": command,
-                "storage": [{"mountPath": "PROJECT_SHARE_AUTO", "containerPath": "/project"}]
+                "storage": [{"hostPath": "PROJECT_SHARE_AUTO", "containerPath": "/project"}]
             },
             "resources": {
                 "clusterId": cluster_id,  # None is fine here
@@ -1912,7 +1914,9 @@ def convert_to_job2(ctx):
             traceback.print_exc()
         raise click.ClickException("Could not parse provided Job (--debug for max details)")
 
-
+@click.command("version", short_help="Show version of the GPULab CLI")
+def show_version():
+    click.echo(GPULAB_VERSION)
 
 cli.add_command(run)
 # cli.add_command(queue)
@@ -1931,6 +1935,7 @@ cli.add_command(sftp)
 cli.add_command(run_interactive)
 cli.add_command(print_bugreport_context)
 cli.add_command(convert_to_job2)
+cli.add_command(show_version)
 
 localhost_mode_cli.add_command(run_fixed_project)
 # localhost_mode_cli.add_command(queue)
@@ -1949,6 +1954,7 @@ localhost_mode_cli.add_command(sftp)
 localhost_mode_cli.add_command(run_interactive)
 localhost_mode_cli.add_command(print_bugreport_context)
 localhost_mode_cli.add_command(convert_to_job2)
+localhost_mode_cli.add_command(show_version)
 
 
 GPULAB_SLAVE_RESERVED_ENVVARS = [
